import argparse
from .core import *

def main():
    parser = argparse.ArgumentParser(
                    prog='calculator',
                    description='Calculator package')
    
    parser.add_argument("operation",choices=['add',"sub","mul","div"])
    parser.add_argument("a", type=float)
    parser.add_argument("b",type=float)

    args=parser.parse_args()

    ops = {
        "add": add,
        "sub": subtract,
        "mul": multiply,
        "div": divide
    }

    result=ops[args.operation](args.a,args.b)

    print(result)



from calculator.core import add,multiply,subtract,divide
import pytest

def test_add():
    assert add(2, 3) == 5

def test_subtract():
    assert subtract(5, 3) == 2

def test_multiply():
    assert multiply(2, 3) == 6

def test_divide():
    assert divide(6, 3) == 2

def test_divide_by_zero():
    with pytest.raises(ValueError):
        divide(5, 0)